{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Graphical elements\n",
    "\n",
    "Here's an overview of extra graphical and structural elements which can be generated through Myst Markdown to use in Jupyterbooks. Three apostrophes (\\`\\`\\`) is used for starting and ending Myst Markdown content. When building structures inside structures, you need to increase the number of apostrophes. For example, if you want a code inside a box inside a tab, the tab has to be initialized with five apostrophes, the box with three apostrophes and the code with three apostrophes."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Boxes\n",
    "\n",
    "```{admonition} Learning goals\n",
    ":class: note\n",
    "Used for learning goals.\n",
    "```\n",
    "\n",
    "```{admonition} Excercises\n",
    ":class: hint\n",
    "Used for excercises.\n",
    "```\n",
    "\n",
    "```{admonition} Remember\n",
    ":class: caution\n",
    "Used for highlighting important stuff.\n",
    "```\n",
    "\n",
    "```{admonition} Warning\n",
    ":class: danger\n",
    "Generally not used.\n",
    "```\n",
    "\n",
    "```{admonition} Error\n",
    ":class: error\n",
    "Generally not used.\n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This was created by the following code in Markdown:\n",
    "````\n",
    "```{admonition} Learning goals\n",
    ":class: note\n",
    "Used for learning goals.\n",
    "```\n",
    "\n",
    "```{admonition} Excercises\n",
    ":class: hint\n",
    "Used for excercises.\n",
    "```\n",
    "\n",
    "```{admonition} Remember\n",
    ":class: caution\n",
    "Used for highlighting important stuff.\n",
    "```\n",
    "\n",
    "```{admonition} Warning\n",
    ":class: danger\n",
    "Generally not used.\n",
    "```\n",
    "\n",
    "```{admonition} Error\n",
    ":class: error\n",
    "Generally not used.\n",
    "```\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Panels\n",
    "\n",
    "Panels are not generally used, but is a possible way of structuring content if it is seen as useful.\n",
    "\n",
    "````{panels}\n",
    "Content of the left panel.\n",
    "\n",
    "![Jupyter Book Badge](https://img.shields.io/badge/Programming-Computational%20thinking-red)\n",
    "\n",
    "---\n",
    "\n",
    "Panel header 2\n",
    "^^^\n",
    "Panel body 2\n",
    "+++\n",
    "Panel footer 2\n",
    "\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Panels can be made with the following code. In the first panel we also have a random badge generated through [shields.io](shields.io). \n",
    "- The panels are separated with ---\n",
    "- The first header is marked with ^^^\n",
    "- The second header is maked with +++\n",
    "\n",
    "`````\n",
    "````{panels}\n",
    "Content of the left panel.\n",
    "\n",
    "[![Jupyter Book Badge](https://img.shields.io/badge/Programming-Computational%20thinking-red)]\n",
    "\n",
    "---\n",
    "\n",
    "Panel header 2\n",
    "^^^\n",
    "Panel body 2\n",
    "+++\n",
    "Panel footer 2\n",
    "```\n",
    "````\n",
    "`````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We can also specify the number of colomns and the format of the borders:"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "````{panels}\n",
    ":column: col-4\n",
    ":card: border-2\n",
    "Header A\n",
    "^^^\n",
    "Body A\n",
    "---\n",
    "Header B\n",
    "^^^\n",
    "Body B\n",
    "---\n",
    "Header C\n",
    "^^^\n",
    "Body C\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Which is generated with the following code:\n",
    "`````\n",
    "````{panels}\n",
    ":column: col-4\n",
    ":card: border-2\n",
    "Header A\n",
    "^^^\n",
    "Body A\n",
    "---\n",
    "Header B\n",
    "^^^\n",
    "Body B\n",
    "---\n",
    "Header C\n",
    "^^^\n",
    "Body C\n",
    "````\n",
    "`````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Dropdowns\n",
    "```{admonition} Hint!\n",
    ":class: tip, dropdown\n",
    "This is mainly used for extra information and hints.\n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Dropdown menus are created by adding the class _dropdown_ to an admonition (box):\n",
    "\n",
    "````\n",
    "```{admonition} Hint!\n",
    ":class: tip, dropdown\n",
    "This is mainly used for extra information and hints.\n",
    "```\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Code is included in dropdowns like this:\n",
    "`````\n",
    "````{admonition} Solution\n",
    ":class: tip, dropdown\n",
    "```{code-block} python\n",
    "for i in range(10):\n",
    "    print(\"You are cool!\")\n",
    "```\n",
    "You can do it like this or you can choose not to.\n",
    "````\n",
    "`````\n",
    "\n",
    "````{admonition} Solution\n",
    ":class: tip, dropdown\n",
    "```{code-block} python\n",
    "for i in range(10):\n",
    "    print(\"You are cool!\")\n",
    "```\n",
    "You can do it like this or you can choose not to.\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Tabs\n",
    "We can create tabs with text and/or coding blocks to separate content, like disciplinary specific such as physics examples, chemistry examples, life science examples and so on.\n",
    "\n",
    "````{tabbed} C++\n",
    "Here's how it's done in C++\n",
    "```{code-block} c++\n",
    "\n",
    "int main(const int argc, const char **argv) {\n",
    "  return 0;\n",
    "}\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Python\n",
    "Here's how it's done in Python\n",
    "```{code-block} python\n",
    "\n",
    "def main():\n",
    "    return\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Java\n",
    "Here's how it's done in Java\n",
    "```{code-block} java\n",
    "\n",
    "class Main {\n",
    "    public static void main(String[] args) {\n",
    "    }\n",
    "}\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Julia\n",
    "Here's how it's done in Julia\n",
    "```{code-block} julia\n",
    "\n",
    "function main()\n",
    "end\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Fortran\n",
    "Here's how it's done in Fortran\n",
    "```{code-block} fortran\n",
    "\n",
    "PROGRAM main\n",
    "END PROGRAM main\n",
    "```\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "These tabs are generated with the following code:\n",
    "`````\n",
    "````{tabbed} C++\n",
    "Here's how it's done in C++\n",
    "```{code-block} c++\n",
    "\n",
    "int main(const int argc, const char **argv) {\n",
    "  return 0;\n",
    "}\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Python\n",
    "Here's how it's done in Python\n",
    "```{code-block} python\n",
    "\n",
    "def main():\n",
    "    return\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Java\n",
    "Here's how it's done in Java\n",
    "```{code-block} java\n",
    "\n",
    "class Main {\n",
    "    public static void main(String[] args) {\n",
    "    }\n",
    "}\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Julia\n",
    "Here's how it's done in Julia\n",
    "```{code-block} julia\n",
    "\n",
    "function main()\n",
    "end\n",
    "```\n",
    "````\n",
    "\n",
    "````{tabbed} Fortran\n",
    "Here's how it's done in Fortran\n",
    "```{code-block} fortran\n",
    "\n",
    "PROGRAM main\n",
    "END PROGRAM main\n",
    "```\n",
    "````\n",
    "`````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Figures\n",
    "You can insert figures like this:\n",
    "````\n",
    "```{figure} ./path/to/figure.jpg\n",
    ":name: label\n",
    "\n",
    "caption\n",
    "```\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Quotes\n",
    "One can also make nicely formatted quotes:\n",
    "\n",
    "```{epigraph}\n",
    "Everybody should learn how to think, because it teaches you how to program.\n",
    "\n",
    "-- Andreas Haraldsrud, 2021\n",
    "```\n",
    "\n",
    "```{epigraph}\n",
    "Jeg vil også ha et sitat.\n",
    "\n",
    "-- Cathrine Tellefsen, 2021\n",
    "```\n",
    "\n",
    "which is made with the following code:\n",
    "````\n",
    "```{epigraph}\n",
    "Everybody should learn how to think, because it teaches you how to program.\n",
    "\n",
    "-- Andreas Haraldsrud, 2021\n",
    "```\n",
    "\n",
    "```{epigraph}\n",
    "Jeg vil også ha et sitat.\n",
    "\n",
    "-- Cathrine Tellefsen, 2021\n",
    "```\n",
    "````"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Pseudocodes\n",
    "For pseudocodes use the code box with language _text_:\n",
    "````\n",
    "```{code-block} text\n",
    "number = 0\n",
    "repeat 10 times:\n",
    "    number = number + 3\n",
    "    show number on screen\n",
    "```\n",
    "````\n",
    "\n",
    "```{code-block} text\n",
    "number = 0\n",
    "repeat 10 times:\n",
    "    number = number + 3\n",
    "    show number on screen\n",
    "```"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.5"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
